@@ -34,6 +34,10 @@ class FakePreseemModel:
         """Insert exact copies of entities from another model into this one."""
         for obj in await other.Company.List():
             FakePreseemModel._companies[obj.uuid] = obj
+        for obj in await other.Element.List():
+            FakePreseemModel._companies[obj.uuid] = obj
+        for obj in await other.Site.List():
+            FakePreseemModel._companies[obj.uuid] = obj
 
 
     """Fake preseem model that implements the python API."""
@@ -65,7 +69,7 @@ class FakePreseemModel:
 
         @classmethod
         async def List(cls, **kwargs):
-            return [copy.deepcopy(x) for x in FakePreseemModel._companies.values() if not x.inactive]
+            return [copy.deepcopy(x) for x in FakePreseemModel._companies.values()]
 
 
     class Element(BaseModelObject):
@@ -94,7 +98,7 @@ class FakePreseemModel:
             company_uuid = kwargs.get('company_uuid')
             assert company_uuid
             # the real impl returns empty list if the company doesn't exist
-            return [copy.deepcopy(x) for x in (FakePreseemModel._elements.get(company_uuid) or {}).values() if not x.inactive]
+            return [copy.deepcopy(x) for x in (FakePreseemModel._elements.get(company_uuid) or {}).values()]
 
         @classmethod
         async def Delete(cls, **kwargs):
@@ -104,7 +108,22 @@ class FakePreseemModel:
             if elems:
                 elem = elems.get(uuid)
                 if elem:
-                    FakePreseemModel._set_inactive(elem)
+                    del elems[uuid]
+
+        @classmethod
+        async def Update(cls, **kwargs):
+            company_uuid = kwargs.get('company_uuid')
+            uuid = kwargs.get('uuid')
+            elems = FakePreseemModel._elements[company_uuid]
+            if elems:
+                elem = elems.get(uuid)
+                for attr, val in kwargs.items():
+                    if attr == 'company_uuid' or attr == 'uuid':
+                        continue
+                    elif attr == 'active' and val is False:
+                        FakePreseemModel._set_inactive(elem)
+                    else:
+                        setattr(elem, attr, val)
 
 
     class Site(BaseModelObject):
@@ -127,7 +146,7 @@ class FakePreseemModel:
             company_uuid = kwargs.get('company_uuid')
             assert company_uuid
             # the real impl returns empty list if the company doesn't exist
-            return [copy.deepcopy(x) for x in (FakePreseemModel._sites.get(company_uuid) or {}).values() if not x.inactive]
+            return [copy.deepcopy(x) for x in (FakePreseemModel._sites.get(company_uuid) or {}).values()]
 
         @classmethod
         async def Delete(cls, **kwargs):
@@ -137,4 +156,4 @@ class FakePreseemModel:
             if sites:
                 site = sites.get(uuid)
                 if site:
-                    FakePreseemModel._set_inactive(site)
+                    del elems[uuid]
