@@ -60,14 +60,25 @@ async def sync_preseem_model(preseem_model, nm_model, company_uuid, system=None,
                 # Create ap if it doesn't exist (by site+name or ideally source_id)
                 model_site = model_sites.get(ap.attributes.get('topology2'))
                 if not model_site:
-                    print("ERR", ap)
                     continue  # shouldn't be possible
-                if (model_site.uuid, ap.attributes['topology1']) not in model_elems:
+                elem = model_elems.get((model_site.uuid, ap.attributes['topology1']))
+                if not elem:
                     if verbose:
                         logging.info('Create element: %s', ap)
                     r = await preseem_model.Element.Create(company_uuid=company_uuid, site_uuid=model_site.uuid, name=ap.attributes['topology1'], management_ip=ap.attributes.get('ip_address'))
                     if verbose:
                         logging.info('Created element: %s', r)
+                else:
+                    # check for changes
+                    updates = {}
+                    if elem.inactive:
+                        updates['inactive'] = False
+                    if elem.management_ip != ap.attributes.get('ip_address'):
+                        updates['management_ip'] = ap.attributes.get('ip_address')
+                    if updates:
+                        if verbose:
+                            logging.info('Update element %s: %s', ap, updates)
+                        await preseem_model.Element.Update(company_uuid=company_uuid, uuid=elem.uuid, **updates)
                 bss_aps.add((model_site.uuid, ap.attributes['topology1']))
 
         if aps and delete:  # only do this if we have APs for multi-system deployments
@@ -75,10 +86,10 @@ async def sync_preseem_model(preseem_model, nm_model, company_uuid, system=None,
                 if elem_id not in bss_aps:
                     if verbose:
                         logging.info('Delete element: %s', elem)
-                    await preseem_model.Element.Delete(uuid=elem.uuid, company_uuid=elem.company_uuid)
+                    await preseem_model.Element.Update(uuid=elem.uuid, company_uuid=elem.company_uuid, active=False)
 
             for site_id, site in model_sites.items():
                 if site_id not in bss_sites:
                     if verbose:
                         logging.info('Delete site: %s', site)
-                    await preseem_model.Site.Delete(uuid=site.uuid, company_uuid=site.company_uuid)
+                    await preseem_model.Site.Update(uuid=site.uuid, company_uuid=site.company_uuid, active=False)
